<?php
//
// BBWA
// variables.php
// ѹѤѿ
// Teppei KAKU <teppei@sat.co.jp>
//

// ǥ쥯ȥΥեѥ (Ǹ˥å/٤ĤƤ)
// :ФΥե륷ƥΥѥǤ
$dirName = "/xxx/xxx/Pics/";
// ǥ쥯ȥ URL (Ǹ˥å/٤ĤƤ)
$picUrl = "http://xxx.xxx/xxx/Pics/";
// إۡڡ٥򥯥åȤ˰ư URL
$homeUrl = "http://xxx.xxx/";

// ͥΥ
$thumbSize = 120;
// ư̾Υ
$autoSize = 800;
// ͥʼ
$quality = 80;
// 1ڡΥͥɽ
$perPage = 10;

// Х̾
$albumTitle = "xxx";
// Хɽβ URL (ɬפʤж)
$bannerImg = "";
// ơ (Themes ǥ쥯ȥʲ CSS եΥե̾ʬ)
$theme = "brown";

// ԥѥ
$adminPass = "xxx";
// TRUE:ԤΤ߿Ʋǽ, FALSE:ïǤ⿷Ʋǽ
$adminOnly = TRUE;
// Ʋǽʥե륵ξ(Хñ)
$maxFileSize = 512;

// ХԤ̾
$adminName = "xxx";
// ХԤΥ᡼륢ɥ쥹 (ɬפʤж)
$adminMail = "";
?>
